@@ -130,11 +130,15 @@ class Block:
             secondly_empty_block = adding
             if not first_empty_block > secondly_empty_block:
                 self.empty_block_number = adding
-            self.start_time = self.genesis_time + (
-                (self.sequence_number + self.empty_block_number) *
-                self.block_time)
-            if self.round_1:
-                self.round_2_starting_time = self.start_time + self.round_1_time
+                self.start_time = self.genesis_time + (
+                    (self.sequence_number + self.empty_block_number) *
+                    self.block_time)
+                if self.round_1:
+                    self.round_2_starting_time = self.start_time + self.round_1_time
+            else:
+                self.start_time = self.genesis_time + (
+                    (self.sequence_number + self.empty_block_number -
+                     self.gap_block_number) * self.block_time)
 
     def dump_json(self):
         """
