@@ -5,10 +5,11 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from contextlib import suppress
+
 from decentra_network.blockchain.block.block_main import Block
 from decentra_network.blockchain.block.get_block import GetBlock
 from decentra_network.lib.log import get_logger
-from decentra_network.wallet.ellipticcurve.wallet_import import wallet_import
+from decentra_network.wallet.wallet_import import wallet_import
 
 logger = get_logger("BLOCKCHAIN")
 
@@ -29,7 +30,8 @@ def CreateBlock(custom_TEMP_BLOCK_PATH=None):
         else:
             previous_hash = current_block.previous_hash
 
-    logger.info("Creating the genesis block and sending it to the connected nodes")
+    logger.info(
+        "Creating the genesis block and sending it to the connected nodes")
 
     if previous_hash is None:
         return Block(wallet_import(-1, 3))
