@@ -12,14 +12,7 @@ def AccountsHash(block, the_accounts):
     Calculates and returns the hash of the accounts.
     """
 
-    new_part = MerkleTree(
-        [account.get_hash() for account in the_accounts]
-    ).getRootHash()
-    account_list = [new_part]
-    account_list.extend(
-        str(edited_account.get_hash()) for edited_account in block.edited_accounts
-    )
-
-    block.edited_accounts.clear()
+    account_list = MerkleTree([account.get_hash()
+                               for account in the_accounts]).getRootHash()
 
     return MerkleTree(account_list).getRootHash()
