@@ -24,7 +24,7 @@ from decentra_network.config import TEMP_BLOCKSHASH_PART_PATH
 from decentra_network.config import TEMP_BLOCKSHASH_PATH
 from decentra_network.consensus.finished.transactions.transactions_main import \
     transactions_main
-from decentra_network.consensus.time.true_time.true_time_main import true_time
+from decentra_network.consensus.finished.true_time.true_time_main import true_time
 from decentra_network.lib.log import get_logger
 from decentra_network.lib.mix.merkle_root import MerkleTree
 from decentra_network.lib.settings_system import save_settings
@@ -109,12 +109,11 @@ def finished_main(
 
             the_blocks_hash = GetBlockshash(
                 custom_TEMP_BLOCKSHASH_PATH=the_TEMP_BLOCKSHASH_PATH)
-            
+
             if len(the_blocks_hash) == block.part_amount:
-                
+
                 block.empty_block_number += block.gap_block_number
-                difference = (block.start_time +  (block.hard_block_number * block.block_time)) - int(time.time())
-                time.sleep(difference)
+
                 block.sync = True
                 SaveBlockshash_part(
                     MerkleTree(the_blocks_hash).getRootHash(),
@@ -143,6 +142,11 @@ def finished_main(
                     )
                 os.remove(the_TEMP_BLOCKSHASH_PATH)
 
+                difference = (block.start_time +
+                              (block.hard_block_number *
+                               block.block_time)) - int(time.time())
+                time.sleep(difference)
+
         PendingtoValidating(block)
         SaveBlock(
             block,
@@ -153,7 +157,7 @@ def finished_main(
         )
         return True
     else:
-        
+
         if block.sync == True:
             block.sync = False
             SaveBlock(
