@@ -12,9 +12,11 @@ import argparse
 
 os.environ["KIVY_NO_ARGS"] = "1"
 from kivy import Config
+from kivy.core.window import Window
 from kivy.lang import Builder
 from kivymd.app import MDApp
 
+import decentra_network.gui.the_decentra_network_gui_app
 from decentra_network.lib.config_system import get_config
 from decentra_network.lib.log import get_logger
 from decentra_network.lib.safety import safety_check
@@ -70,43 +72,73 @@ class GUI(MDApp):
         """
         Some configurations.
         """
+        Window.borderless = True
         value = the_settings()["dark_mode"]
         self.theme_cls.theme_style = "Dark" if value else "Light"
         self.theme_cls.primary_palette = "Green"  # "Purple", "Red"
 
-        FONT_PATH = os.path.join(os.environ["DECENTRA_ROOT"], "gui_lib",
-                                 "fonts")
+        self.FONT_PATH = os.path.join(os.environ["DECENTRA_ROOT"], "gui_lib",
+                                      "fonts")
 
         self.theme_cls.font_styles.update({
-            "H1": [os.path.join(FONT_PATH, "Poppins-Light"), 96, False, -1.5],
-            "H2": [os.path.join(FONT_PATH, "Poppins-Light"), 60, False, -0.5],
-            "H3": [os.path.join(FONT_PATH, "Poppins-Regular"), 48, False, 0],
-            "H4":
-            [os.path.join(FONT_PATH, "Poppins-Regular"), 34, False, 0.25],
-            "H5": [os.path.join(FONT_PATH, "Poppins-Regular"), 24, False, 0],
-            "H6": [os.path.join(FONT_PATH, "Poppins-Bold"), 20, False, 0.15],
+            "H1":
+            [os.path.join(self.FONT_PATH, "Poppins-Light"), 96, False, -1.5],
+            "H2":
+            [os.path.join(self.FONT_PATH, "Poppins-Light"), 60, False, -0.5],
+            "H3":
+            [os.path.join(self.FONT_PATH, "Poppins-Regular"), 48, False, 0],
+            "H4": [
+                os.path.join(self.FONT_PATH, "Poppins-Regular"),
+                34,
+                False,
+                0.25,
+            ],
+            "H5":
+            [os.path.join(self.FONT_PATH, "Poppins-Regular"), 24, False, 0],
+            "H6":
+            [os.path.join(self.FONT_PATH, "Poppins-Bold"), 20, False, 0.15],
             "Subtitle1": [
-                os.path.join(FONT_PATH, "Poppins-Regular"),
+                os.path.join(self.FONT_PATH, "Poppins-Regular"),
                 16,
                 False,
                 0.15,
             ],
             "Subtitle2": [
-                os.path.join(FONT_PATH, "Poppins-Medium"),
+                os.path.join(self.FONT_PATH, "Poppins-Medium"),
                 14,
                 False,
                 0.1,
             ],
-            "Body1":
-            [os.path.join(FONT_PATH, "Poppins-Regular"), 16, False, 0.5],
-            "Body2":
-            [os.path.join(FONT_PATH, "Poppins-Light"), 14, False, 0.25],
-            "Button":
-            [os.path.join(FONT_PATH, "Poppins-Bold"), 14, True, 1.25],
-            "Caption":
-            [os.path.join(FONT_PATH, "Poppins-Regular"), 12, False, 0.4],
-            "Overline":
-            [os.path.join(FONT_PATH, "Poppins-Regular"), 10, True, 1.5],
+            "Body1": [
+                os.path.join(self.FONT_PATH, "Poppins-Regular"),
+                16,
+                False,
+                0.5,
+            ],
+            "Body2": [
+                os.path.join(self.FONT_PATH, "Poppins-Light"),
+                14,
+                False,
+                0.25,
+            ],
+            "Button": [
+                os.path.join(self.FONT_PATH, "Poppins-Bold"),
+                14,
+                True,
+                1.25,
+            ],
+            "Caption": [
+                os.path.join(self.FONT_PATH, "Poppins-Regular"),
+                12,
+                False,
+                0.4,
+            ],
+            "Overline": [
+                os.path.join(self.FONT_PATH, "Poppins-Regular"),
+                10,
+                True,
+                1.5,
+            ],
         })
 
         return Builder.load_string(KV)
@@ -114,7 +146,10 @@ class GUI(MDApp):
     def restart(self):
         self.root.clear_widgets()
         self.stop()
-        return GUI().run()
+        decentra_network.gui.the_decentra_network_gui_app.the_decentra_network_gui = (
+            GUI())
+        return (decentra_network.gui.the_decentra_network_gui_app.
+                the_decentra_network_gui.run())
 
 
 def arguments():
@@ -145,7 +180,11 @@ def arguments():
 
     safety_check(args.interface, args.timeout)
 
-    GUI().run()
+    decentra_network.gui.the_decentra_network_gui_app.the_decentra_network_gui = GUI(
+    )
+
+    decentra_network.gui.the_decentra_network_gui_app.the_decentra_network_gui.run(
+    )
 
 
 def start():
