@@ -7,9 +7,19 @@ from kivymd.uix.behaviors import RectangularRippleBehavior
 from kivymd.uix.boxlayout import MDBoxLayout
 from kivymd.uix.screen import MDScreen
 
+import decentra_network.gui.the_decentra_network_gui_app
+from decentra_network.gui.popup import popup
+
 
 class DecentraRootScreen(MDScreen):
-    pass
+
+    def close_app(self, widget=None):
+        self.close_app_dialog = popup(
+            text="Are you sure you want to close ?",
+            target=decentra_network.gui.the_decentra_network_gui_app.
+            the_decentra_network_gui.stop,
+            type="question",
+        )
 
 
 class DecentraListItem(ThemableBehavior, RectangularRippleBehavior,
