@@ -4,13 +4,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
-from decentra_network.wallet.ellipticcurve.wallet_import import wallet_import
-from decentra_network.wallet.ellipticcurve.get_saved_wallet import get_saved_wallet 
-
 from decentra_network.lib.mix.mixlib import menu_maker
 from decentra_network.lib.settings_system import the_settings
+from decentra_network.wallet.get_saved_wallet import get_saved_wallet
+from decentra_network.wallet.wallet_import import wallet_import
 
 
 def print_wallets():
@@ -28,9 +25,8 @@ def print_wallets():
         if current_wallet != number:
             text = menu_maker(menu_number=number, menu_text=address)
         else:
-            text = menu_maker(
-                menu_number=number, menu_text=f"{address} - CURRENTLY USED"
-            )
+            text = menu_maker(menu_number=number,
+                              menu_text=f"{address} - CURRENTLY USED")
         print(text)
         result.append(text)
     return result
