@@ -4,16 +4,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
-from decentra_network.wallet.ellipticcurve.get_saved_wallet import get_saved_wallet 
-
-from decentra_network.wallet.print_wallets import print_wallets
-
-
-from decentra_network.lib.settings_system import change_wallet
-
 from decentra_network.lib.log import get_logger
+from decentra_network.lib.settings_system import change_wallet
+from decentra_network.wallet.get_saved_wallet import get_saved_wallet
+from decentra_network.wallet.print_wallets import print_wallets
 
 logger = get_logger("WALLET")
 
